Re: Comctl32.StrStrIW implementation

2002-12-11 Thread Dmitry Timoshkov
"Robert Shearman" <[EMAIL PROTECTED]> wrote:

> StrStrIW is used by native Regedit when searching the registry. This patch
> enables this function of Regedit to work.
> 
> ChangeLog:
> - Implement StrStrIW (find a string inside a string)

> + first = towlower (*lpStr2);
> + while (len1 >= len2) {
> + if (towlower(*lpStr1) == first) {

It almost always is a bad idea to use unicode or locale dependant functions
from a system libc (isalpha() in your other patch). It could sometimes produce
bad side effects due to different unicode implementations and the fact that
Wine's default ANSI code page often is not the same as a one used by an underlying
system. The best way to avoid discrepancies is to use Win32 APIs to deal
with locale sensitive data. Other way to avoid use of the libc locale
dependant functions is to delegate all the work to unicode version of
the API and leaving to ANSI version only simple work of converting strings
to unicode and adopting the returned data if necessary.

-- 
Dmitry.







Houston, we have a problem...

2002-12-11 Thread Dimitrie O. Paun
Configure finished.  Do 'make depend && make' to compile Wine.

cd `dirname dlls/__depend__` && make depend
make[1]: Entering directory `/opt/dimi/dev/wine/wine/dlls'
cd `dirname advapi32/__depend__` && make depend
make[2]: Entering directory `/opt/dimi/dev/wine/wine/dlls/advapi32'
cd `dirname tests/__depend__` && make depend
make[3]: Entering directory `/opt/dimi/dev/wine/wine/dlls/advapi32/tests'
../../../tools/makedep -I../../../../wine.src/dlls/advapi32/tests -I. 
-I../../../../wine.src/include -I../../../include  
-C../../../../wine.src/dlls/advapi32/tests registry.c testlist.c
../../../../wine.src/dlls/advapi32/tests/testlist.c: No such file or directory
make[3]: *** [depend] Error 1
make[3]: Leaving directory `/opt/dimi/dev/wine/wine/dlls/advapi32/tests'
make[2]: *** [tests/__depend__] Error 2
make[2]: Leaving directory `/opt/dimi/dev/wine/wine/dlls/advapi32'
make[1]: *** [advapi32/__depend__] Error 2
make[1]: Leaving directory `/opt/dimi/dev/wine/wine/dlls'
make: *** [dlls/__depend__] Error 2

-- 
Dimi.





Re: Wine conformance testing on native platforms

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 12:21 pm, Luke Stras wrote:
> Dimi, I see that you've added me as a "volunteer" for running the
> conformance tests on NT.  Gee, thanks :).

You're welcome! :)

> In any case, I don't mind doing this.  However, I have a question : what
> should I do with the test results?  Posting them to wine-devel every
> time a test changes seems somewhat high-bandwidth...

Well, theoretically these tests should not fail. So once we fix them,
you should post a message to wine-devel if and only if you notice a 
failure.

> What we (i.e., the testers) could do is to keep track of what changes
> between successive test runs, I guess, and we could just post a summary
> of the changes.

Yes, that would be useful to track progress until we get all tests fixed.
diff(1) is your friend. But once the tests are fixed, you only need to
post if you notice any failure, as explained above.

> This brings up another point: these test results should be put up
> somewhere on the Web for everyone to see.  Might I suggest putting them
> up on the Wine Janitorial Projects page?  For every platform, just put
> in a link to "Most recent test results", say.

I've added a link there to the binaries posted by Francois. Would you
prefer something else?

> One last thing: is there any way to be automatically notified whenever
> the available test suite changes?

I suggested it, but someone has to
  1. Write a script that build the tests, creates an archive, compares the
 result with the previous build, and if different, emails the guys on
 the testing list
  2. We need a volunteer that runs the script from time to time
 (say sets up a cron job on a box that does 
cd "$WINEROOT" && cvs up && tools/update-tests
  or something like this)

I've also included on the 'Fun Projects' page an idea for a nice test
harness (a la JUnit). Check it out -- perfect project for a newbie with
some Win32 programming experience.

-- 
Dimi.





Re: Serious problem with / and mount points

2002-12-11 Thread Jeff Smith
What I have so far:
 in files/dos_fs.c:1343, drive is receiving the value -1.
 at line 1358, this is blindly added to 'A'.  As you may
 know, in ASCII, 'A' - 1 = '@'.

 The next step is to determine why DRIVE_FindDriveRoot is
 returning -1.

 BTW, the same occurred in the reverse situation:
   (konsole) mount /mnt/cdrom
   (konsole) wcmd
   (wcmd) D:
   (wcmd) dir
   (konsole) umount /mnt/cdrom
   (wcmd) dir
 Now I am at @>
 If I remount and dir again, I am back to D>


From: Sylvain Petreolle <[EMAIL PROTECTED]>

Trying to read a dvd rom that wasn't mounted,

I did "dir" in wcmd. The label of the disc was displayed and "file not
found".
C>d:
D>dir
Volume in drive D is SPY_KIDS
Volume Serial Number is 1234-5678

File not found

  0 bytes free
D>

I then mounted the dvd and typed "dir" again.
D>dir
Volume in drive D is SPY_KIDS
Volume Serial Number is 1234-5678

Directory of D:\

01/01/1970  01:00:00   a_imprim
01/01/1970  01:00:00   audio_ts
...
   2 files7,904 bytes
   7 directories  0 bytes free

@>

It appears that the '@' letter is normally inexistant and points to the
root of the system, '/' directory (my dvd is mounted under /mnt/dvd).

@>cd
@:\mnt\dvd
@>

When trying to do "cd ..", the command silently fails and does nothing.

Comments ?


_
MSN 8 helps eliminate e-mail viruses. Get 2 months FREE*. 
http://join.msn.com/?page=features/virus




Re: Fix shell32.ExtractIcon with A->W and 32 -> 16 calls

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 04:47 pm, Rolf Kalbermatter wrote:

Patrik,

How come winapi_check did not pick up this one as a bad
32->16 cross call?

>  /*
>   * ExtractIconA[SHELL32.@]
> - *
> - * FIXME
> - *  if the filename is not a file return 1
>   */
> -HICON WINAPI ExtractIconA( HINSTANCE hInstance, LPCSTR lpszExeFileName,
> -   UINT nIconIndex )
> -{   HGLOBAL16 handle = 
>InternalExtractIcon16(HINSTANCE_16(hInstance),lpszExeFileName,nIconIndex, 1);
> -TRACE("\n");
> -if( handle )
> -{
> -   HICON16* ptr = (HICON16*)GlobalLock16(handle);
> -   HICON16  hIcon = *ptr;
> -
> -   GlobalFree16(handle);
> -   return HICON_32(hIcon);
> -}
> -return 0;

-- 
Dimi.





Re: wine/ tools/winebuild/winebuild.man.in tools/w ...

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 09:20 pm, Alexandre Julliard wrote:
> Removed the -noimport flag in spec files.

Alexandre, mind if you explain in a few words the rationale 
for this one? Not that I have a problem with it, but I like
to know where you're going... :)

TIA, 
Dimi.





WinXP Professional conformance test update

2002-12-11 Thread David Miller
Here are the results of all the tests which produced different results 
today using the new binaries, as well as output from tests I didn't run 
previously because I didn't realize they existed.  (I followed the script)

C:\winetests>dsound_test.exe dsound
dsound.c:56:Testing Primary Sound Driver -
dsound.c:70:  DirectSound Caps: flags=0x0f5f secondary min=5000 max=44100
dsound.c:100:  PrimaryBuffer Caps: flags=0x0009 size=32768
dsound.c:113:  tag=0x0001 22050x8x2 avg.B/s=44100 align=2
dsound.c:129:  status=0x
dsound.c:56:Testing Sound Blaster AWE64 - ctlsb16.sys
dsound.c:70:  DirectSound Caps: flags=0x0f5f secondary min=5000 max=44100
dsound.c:100:  PrimaryBuffer Caps: flags=0x0009 size=32768
dsound.c:113:  tag=0x0001 22050x8x2 avg.B/s=44100 align=2
dsound.c:129:  status=0x
dsound: 27 tests executed, 0 marked as todo, 0 failures.

C:\winetests>kernel32_test.exe file
file.c:633:Current offset = 0015
file.c:658:Current offset = 0015
file: 487239 tests executed, 0 marked as todo, 0 failures.

C:\winetests>kernel32_test.exe path
path.c:514: Test failed: GetLongPathNameA: wrong return code, 106 instead of 46
path.c:889:TMP=C:\DOCUME~1\ADMINI~1\LOCALS~1\Temp
path.c:900:TMP=C:\WINDOWS
path.c:910:TMP=C:\
path.c:920:TMP=C:
path: 1800 tests executed, 0 marked as todo, 1 failure.


C:\winetests>msvcrt_test.exe scanf
scanf: 6 tests executed, 0 marked as todo, 0 failures.

C:\winetests>kernel32_test.exe generated
generated: 609 tests executed, 0 marked as todo, 0 failures.

C:\winetests>shlwapi_test.exe generated
generated: 19 tests executed, 0 marked as todo, 0 failures.

C:\winetests>shell32_test.exe generated
generated: 272 tests executed, 0 marked as todo, 0 failures.

C:\winetests>user32_test.exe generated
generated: 1524 tests executed, 0 marked as todo, 0 failures.

C:\winetests>wininet_test.exe generated
generated: 252 tests executed, 0 marked as todo, 0 failures.




RE: advapi32_test registry 3 errors vs 31 errors

2002-12-11 Thread Kye Lewis
Looks like it's:

shlwapi_test.exe shreg

that has a problem.

Any easy way of narrowing down even further (ie. Running the individual
tests separately?)

-Original Message-
From: [EMAIL PROTECTED] [mailto:[EMAIL PROTECTED]]
On Behalf Of Kye Lewis
Sent: Thursday, December 12, 2002 3:55 PM
To: [EMAIL PROTECTED]
Subject: advapi32_test registry 3 errors vs 31 errors

Hi,

Just ran the conformance tests on my laptop:

The first time I went through I got 3 errors, the second time I got 31
So I get the feeling that one of the tests (maybe even that one) is
doing something weird.
I’m on a quest now to find out which one (if any!)

Thanks,
Kye Lewis
 

You can reach me at:
[EMAIL PROTECTED] at most times
[EMAIL PROTECTED] from 9am to 3pm Monday to Friday
[EMAIL PROTECTED] is an alternative email







advapi32_test registry 3 errors vs 31 errors

2002-12-11 Thread Kye Lewis
Hi,

Just ran the conformance tests on my laptop:

The first time I went through I got 3 errors, the second time I got 31
So I get the feeling that one of the tests (maybe even that one) is
doing something weird.
I’m on a quest now to find out which one (if any!)

Thanks,
Kye Lewis
 

You can reach me at:
[EMAIL PROTECTED] at most times
[EMAIL PROTECTED] from 9am to 3pm Monday to Friday
[EMAIL PROTECTED] is an alternative email






Serious problem with / and mount points

2002-12-11 Thread Sylvain Petreolle
Trying to read a dvd rom that wasn't mounted,

I did "dir" in wcmd. The label of the disc was displayed and "file not
found".
C>d: 
D>dir
Volume in drive D is SPY_KIDS
Volume Serial Number is 1234-5678
 
File not found   
 
  0 bytes free   
D>

I then mounted the dvd and typed "dir" again.
D>dir   
Volume in drive D is SPY_KIDS   
Volume Serial Number is 1234-5678   

Directory of D:\

01/01/1970  01:00:00   a_imprim
01/01/1970  01:00:00   audio_ts
...
   2 files7,904 bytes 
   7 directories  0 bytes free
  
@>

It appears that the '@' letter is normally inexistant and points to the
root of the system, '/' directory (my dvd is mounted under /mnt/dvd).

@>cd  
@:\mnt\dvd
@>

When trying to do "cd ..", the command silently fails and does nothing.

Comments ?

=
Sylvain Petreolle
[EMAIL PROTECTED] 
Fight against Spam ! http://www.euro.cauce.org/en/index.html
ICQ #170597259

"Don't think you are. Know you are." Morpheus in Matrix, chapter 15.

___
Do You Yahoo!? -- Une adresse @yahoo.fr gratuite et en français !
Yahoo! Mail : http://fr.mail.yahoo.com




Re: Fix the kernel/locale tests

2002-12-11 Thread Francois Gouget
On Wed, 11 Dec 2002, Mehmet YASAR wrote:
[...]
> I'm the author of the locale test. It has been written mainly to help
> fixing bug 367 (see http://bugs.winehq.com/show_bug.cgi?id=637) and
> that's why it is testing undocumented behavior.
>
> Two application like "HTMLKit" or "Font xplorer lite" rely on this weird
> behavior.

Ah, that's interesting. However, reading the bug it sounds like the
problem was with GetLocaleInfoA, not the other functions. That makes
sense since that test did not fail on any platform (and thus I did not
change it).

So I propose to just add a comment for that specific test, mentioning
the two applications and the bug report. Maybe the comment should also
mention the ExpressBars library. If anyone has suggestions for a better
wording let me know.

Here's the patch (but it conflicts with the one I already sent due to
the memset/sizeof changes so I'll send it to wine-patches when the
previous one has been committed).


Index: dlls/kernel/tests/locale.c
===
RCS file: /home/wine/wine/dlls/kernel/tests/locale.c,v
retrieving revision 1.7
diff -u -r1.7 locale.c
--- dlls/kernel/tests/locale.c  27 Nov 2002 20:13:23 -  1.7
+++ dlls/kernel/tests/locale.c  12 Dec 2002 00:26:04 -
@@ -51,6 +51,9 @@
lcid = MAKELCID(MAKELANGID(LANG_ENGLISH, SUBLANG_ENGLISH_US), SORT_DEFAULT );
ok (lcid == 0x409, "wrong LCID calculated");

+/* HTMLKit and "Font xplorer lite" expect GetLocaleInfoA to
+ * partially fill the buffer even if it is too short. See bug 637.
+ */
strcpy(Expected, "x");
memset( buffer, 'x', sizeof (buffer)/sizeof(buffer[0]) );
ret = GetLocaleInfoA(lcid, LOCALE_SDAYNAME1, buffer, 0);


-- 
Francois Gouget [EMAIL PROTECTED]http://fgouget.free.fr/
 Avoid the Gates of Hell - use Linux.





Resend of Win98 Conformance Test Output

2002-12-11 Thread Dustin Navea
I guess it would help if I actually attached the zip

wine-tests-output-Win98-Regular-lan-sound.zip
Description: wine-tests-output-Win98-Regular-lan-sound.zip


Ran conformance tests on Win98 Regular (My output)

2002-12-11 Thread Dustin Navea
Ok, you can add me to Win98 (non-SE) testing as well as Win2k (SP3) testing, here is the zipped output of the conformance tests, I ran each test individually (instead of using runtests.bat) and sometimes had to run it 2 or more times to get all of the output because for some reason Win98 on this box (at work) isnt letting me redirect output to a file...go figure.  Anyways, here it is for anyone that wants it..

Re: Windows ME test results

2002-12-11 Thread Jeff Smith
From: James K Whiting <[EMAIL PROTECTED]>

Here are the test results.

Would it be possible to have the tests just output to a file? I was unable
to redirect anything to a file, and windows makes it unbelievably annoying
to copy and paste text between programs. Further instructions on capturing
the output would be useful, since I have only used Windows for web browsing
and verifying that hardware works, so I haven't learned how anything works
and my memories of DOS are very vague now.

James


Tony Lambregts just submitted a patch to make the test output go to
stdout rather than stderr.  This should make it possible to redirect
the output to a file.

Using the precompiled tests on Francois Gouget's site, 
http://fgouget.free.fr/wine/, you should be able to unzip the archive, and 
execute this at the DOS prompt:

runtests > output_file

Of course, Francois' test will need to be updated with the patch first.

-- Jeff S

_
STOP MORE SPAM with the new MSN 8 and get 2 months FREE* 
http://join.msn.com/?page=features/junkmail




RE: Wine, Windows.Forms on Linux, GC and segfaults.

2002-12-11 Thread Miguel de Icaza
Hello,

> > The problem is that by the time that Wine has been initialized,
> > using setjmp/longjmp will always lead to a crash.  The code 
> > in pthreads
> > that performs the longjmp will first try to invoke the pthread cleanup
> > routines, and then invoke longjmp.  This never happens.
> 
> You can't and needn't link with -lpthread. Wine has its own
> pthread implmentation.
> 
> I tried your included code and it works just fine unless you
> link with -lpthread, then it crashes in the same way as in your
> attached picture. But then you should never link Wine with
> -lpthread so that is not really a bug.
> 
> Of course Wine pthread implementation it not in any way complete
> so some function might be missing and some might only be only
> partially implemented and of course some might be incorrectly
> implemented.
> 
> So please try again without linking with -lpthread.

The problem is that this is very hard for us to do as two of the
underlying libraries we are using (libmono and libgc) both link against
pthread to achieve their threading capabilities.

It might be better to investigate what are Wine's requirements for
having its own pthread implementation, and have those changed pushed to
the maintainers of pthreads.

In particular, we are interested in using WineLib, maybe it would be
possible to have WineLib use the standard pthread implementation instead
of rolling its own?

Miguel.




Re: Fix the kernel/locale tests

2002-12-11 Thread Mehmet YASAR
Francois Gouget wrote:


So undocumented features should not be tested unless there is a really
good reason to do so. Unless you know of a specific application that
depends on it, there is no good reason to check whether a buffer is or
is not modified when it is too short.


Hi,

I'm the author of the locale test. It has been written mainly to help 
fixing bug 367 (see http://bugs.winehq.com/show_bug.cgi?id=637) and 
that's why it is testing undocumented behavior.

Two application like "HTMLKit" or "Font xplorer lite" rely on this weird 
behavior.

Mehmet




Re: W2K results from the current tests

2002-12-11 Thread Justin

- Original Message -
From: "Rolf Kalbermatter" <[EMAIL PROTECTED]>
To: <[EMAIL PROTECTED]>
Sent: Wednesday, December 11, 2002 12:10 PM
Subject: RE: W2K results from the current tests


> W2K results from the current tests as downloaded from
http://fgouget.free.fr/wine/winetests.zip
>
> They seem to match the WinXP tests mostly ;-).
>
> Just one remark. The tests output all there results on stderr so to
redirect
> all info into a file when starting the batch file the command
>
> runtests.bat>>result.txt 2>&1
>

Doesn't work on WinME :-(

Kevin





Re: W2K results from the current tests

2002-12-11 Thread Tony Lambregts
Rolf Kalbermatter wrote:


As far as I'm concerned I don't see why test results should go to stderr.
But I do not know about the possible background on Unix platforms for this.
If you want to do a patch I think this would be helpful and then see if
Alexandre is committing it ;-)

Rolf Kalbermatter


 

Yeah your right

Change Log: direct the output of the tests to stdout so that Win98 can 
redirect the output to a file.

Files: wine/include/test.h

--

Tony Lambregts


Index: test.h
===
RCS file: /home/wine/wine/include/wine/test.h,v
retrieving revision 1.8
diff -u -r1.8 test.h
--- test.h  11 Dec 2002 00:17:42 -  1.8
+++ test.h  11 Dec 2002 20:36:53 -
@@ -119,7 +119,7 @@
 
 static void exit_process( int code )
 {
-fflush( stderr );
+fflush( stdout );
 ExitProcess( code );
 }
 
@@ -156,16 +156,16 @@
 {
 if (condition)
 {
-fprintf( stderr, "%s:%d: Test succeeded inside todo block",
+fprintf( stdout, "%s:%d: Test succeeded inside todo block",
  data->current_file, data->current_line );
 if (msg && msg[0])
 {
 va_start(valist, msg);
-fprintf(stderr,": ");
-vfprintf(stderr, msg, valist);
+fprintf(stdout,": ");
+vfprintf(stdout, msg, valist);
 va_end(valist);
 }
-fputc( '\n', stderr );
+fputc( '\n', stdout );
 InterlockedIncrement(&todo_failures);
 return 0;
 }
@@ -175,23 +175,23 @@
 {
 if (!condition)
 {
-fprintf( stderr, "%s:%d: Test failed",
+fprintf( stdout, "%s:%d: Test failed",
  data->current_file, data->current_line );
 if (msg && msg[0])
 {
 va_start(valist, msg);
-fprintf( stderr,": ");
-vfprintf(stderr, msg, valist);
+fprintf( stdout,": ");
+vfprintf(stdout, msg, valist);
 va_end(valist);
 }
-fputc( '\n', stderr );
+fputc( '\n', stdout );
 InterlockedIncrement(&failures);
 return 0;
 }
 else
 {
 if (report_success)
-fprintf( stderr, "%s:%d: Test succeeded\n",
+fprintf( stdout, "%s:%d: Test succeeded\n",
  data->current_file, data->current_line);
 InterlockedIncrement(&successes);
 }
@@ -206,9 +206,9 @@
 
 if (winetest_debug > 0)
 {
-fprintf( stderr, "%s:%d:", data->current_file, data->current_line );
+fprintf( stdout, "%s:%d:", data->current_file, data->current_line );
 va_start(valist, msg);
-vfprintf(stderr, msg, valist);
+vfprintf(stdout, msg, valist);
 va_end(valist);
 }
 }
@@ -272,7 +272,7 @@
 
 if (!(test = find_test( name )))
 {
-fprintf( stderr, "Fatal: test '%s' does not exist.\n", name );
+fprintf( stdout, "Fatal: test '%s' does not exist.\n", name );
 exit_process(1);
 }
 successes = failures = todo_successes = todo_failures = 0;
@@ -282,7 +282,7 @@
 
 if (winetest_debug)
 {
-fprintf( stderr, "%s: %ld tests executed, %ld marked as todo, %ld %s.\n",
+fprintf( stdout, "%s: %ld tests executed, %ld marked as todo, %ld %s.\n",
  name, successes + failures + todo_successes + todo_failures,
  todo_successes, failures + todo_failures,
  (failures + todo_failures != 1) ? "failures" : "failure" );
@@ -297,9 +297,9 @@
 {
 const struct test *test;
 
-fprintf( stderr, "Usage: %s test_name\n", argv0 );
-fprintf( stderr, "\nValid test names:\n" );
-for (test = winetest_testlist; test->name; test++) fprintf( stderr, "%s\n", 
test->name );
+fprintf( stdout, "Usage: %s test_name\n", argv0 );
+fprintf( stdout, "\nValid test names:\n" );
+for (test = winetest_testlist; test->name; test++) fprintf( stdout, "%s\n", 
+test->name );
 exit_process(1);
 }
 



Windows ME test results

2002-12-11 Thread James K Whiting
Here are the test results.

Would it be possible to have the tests just output to a file? I was unable
to redirect anything to a file, and windows makes it unbelievably annoying
to copy and paste text between programs. Further instructions on capturing
the output would be useful, since I have only used Windows for web browsing
and verifying that hardware works, so I haven't learned how anything works
and my memories of DOS are very vague now.

James

-
C:\My Documents\winetests>advapi32_test.exe registry
registry.c:80: Test failed: data_count set to 24 instead of 7
registry.c:81: Test failed: type 2 is not REG_SZ
registry.c:94: Test failed: data_count set to 24 instead of 7
registry.c:95: Test failed: type 2 is not REG_SZ
registry.c:96: Test failed: value set to 'xx' instead of 'Te'
registry.c:97: Test failed: data set to 'xx' instead of 'foobar'
registry.c:108: Test failed: data_count set to 24 instead of 7
registry.c:109: Test failed: type 2 is not REG_SZ
registry.c:111: Test failed: data set to 'xx' instead of 'foobar'
registry.c:122: Test failed: data_count set to 24 instead of 7
registry.c:123: Test failed: type 2 is not REG_SZ
registry.c:134: Test failed: expected ERROR_SUCCESS, got 234
registry.c:135: Test failed: val_count set to 20 instead of 4
registry.c:136: Test failed: data_count set to 24 instead of 7
registry.c:137: Test failed: type 2 is not REG_SZ
registry.c:138: Test failed: value is 'xx' instead of Test
registry.c:139: Test failed: data is 'xx' instead of foobar
registry.c:153: Test failed: expected ERROR_MORE_DATA, got 0
registry.c:155: Test failed: data_count set to 2 instead of 7*sizeof(WCHAR)
registry.c:156: Test failed: type 1234 is not REG_SZ
registry.c:167: Test failed: expected ERROR_MORE_DATA, got 0
registry.c:169: Test failed: data_count set to 20 instead of 7*sizeof(WCHAR)
registry.c:170: Test failed: type 1234 is not REG_SZ
registry.c:181: Test failed: expected ERROR_MORE_DATA, got 0
registry.c:182: Test failed: val_count set to 20 instead of 4
registry.c:183: Test failed: data_count set to 2 instead of 7*sizeof(WCHAR)
registry.c:184: Test failed: type 1234 is not REG_SZ
registry.c:185: Test failed: value is not 'Test'
registry.c:196: Test failed: val_count set to 20 instead of 4
registry.c:197: Test failed: data_count set to 20 instead of 7*sizeof(WCHAR)
registry.c:198: Test failed: type 1234 is not REG_SZ
registry.c:199: Test failed: value is not 'Test'
registry.c:200: Test failed: data is not 'foobar'

brings up a dialog box that says:
-
Advapi32_test has caused an error in
ADVAPI32_TEST.EXE.
Advapi32_test will now close

If you continue to experience problems,
try restarting your computer.
-

C:\My Documents\winetests>dsound_test.exe dsound
dsound.c:56:Testing Primary Sound Driver -
dsound.c:70:  DirectSound Caps: flags=0x0f5f secondary min=4800 max=48000
dsound.c:100:  PrimaryBuffer Caps: flags=0x0009 size=32768
dsound.c:113:  tag=0x0001 22050x8x2 avg.B/s=44100 align=2
dsound.c:129:  status=0x
dsound.c:56:Testing ESS Maestro - es198x.sys
dsound.c:70:  DirectSound Caps: flags=0x0f5f secondary min=4800 max=48000
dsound.c:100:  PrimaryBuffer Caps: flags=0x0009 size=32768
dsound.c:113:  tag=0x0001 22050x8x2 avg.B/s=44100 align=2
dsound.c:129:  status=0x
dsound.c:56:Testing Game Compatible Device (emulated) - WaveOut 1
dsound.c:58: Test failed: DirectSoundCreate failed: 0x8878000a

dsound.c:56:Testing Voice Modem Wave #00 Line (emulated) - WaveOut 2
dsound.c:58: Test failed: DirectSoundCreate failed: 0x8878000a

dsound: 29 tests executed, 0 marked as todo, 2 failures.

C:\My Documents\winetests>kernel32_test.exe alloc
alloc.c:159: Test failed: The size
alloc.c:223: Test failed: GlobalReAlloc failed to convert FIXED to MOVEABLE
alloc.c:228: Test failed: Converting from FIXED to MOVEABLE didn't REALLY work
alloc.c:259: Test failed: Discarded memory we shouldn't have
alloc.c:261: Test failed: GlobalUnlock Failed.
alloc.c:316: Test failed: LocalUnlock Failed.
alloc: 58 tests executed, 0 marked as todo, 6 failures.

C:\My Documents\winetests>kernel32_test.exe atom
atom.c:55:WARNING: Unicode atom APIs are not supported on this platform
atom: 163850 tests executed, 0 marked as todo, 0 failures.

C:\My Documents\winetests>kernel32_test.exe codepage
codepage.c:40: Test failed: any negative value should work as strlen() + 1
codepage: 2 tests executed, 0 marked as todo, 1 failure.

C:\My Documents\winetests>kernel32_test.exe directory
directory: 25 tests executed, 0 marked as todo, 0 failures.

C:\My Documents\winetests>kernel32_test.exe environ
environ: 19 tests executed, 0 marked as todo, 0 failures.

C:\My Documents\winetests>kernel32_test.exe file
file.c:631: Test failed: WriteFile error 183
file.c:632: Test failed: expected number of bytes written 0
file.c:633:C

Re: Wineboot

2002-12-11 Thread Shachar Shemesh
Matthew Davison wrote:


I recently requested a copy of the wineboot program, which i obtained
from the mailing list, however this code is somewhat old. Does anyone
have a newer version of this code, or has it not been changed since the
version I have (6/02, i think). Either way i am considering improving
parts of this program, and would like to know if i will be duplicating
any work.
 

I have vulenteered to do likewise. I have not, however, managed to get 
any statement from Andy regarding the current state, or any other 
replies. If he replies to this email, great. If not, I suggest we work 
on it together.

   Shachar






Re: [patch] revert part of Aug 26 change in winmm/wineoss/audio.cthat broke msvc++4.0 installer?

2002-12-11 Thread Dan Kegel
Eric Pouech wrote:

I tried each individually, and neither helped.  Only the two
changes together yielded a wine that properly terminated
when I clicked on the "Exit" button in msvc4++'s installer.
- Dan


a more complete fix should be included
could you try if it works fine ?


It does, thanks!

Now on to figuring out why none of the *other* buttons
in the installer do anything :-(
- Dan




Index: dlls/winmm/wineoss/audio.c
===
RCS file: /home/cvs/cvsroot/wine/wine/dlls/winmm/wineoss/audio.c,v
retrieving revision 1.65
diff -u -r1.65 audio.c
--- dlls/winmm/wineoss/audio.c	4 Nov 2002 22:39:19 -	1.65
+++ dlls/winmm/wineoss/audio.c	11 Dec 2002 20:21:45 -
@@ -1147,8 +1171,12 @@
 TRACE("fragments=%d/%d, fragsize=%d, bytes=%d\n",
 	  dspspace.fragments, dspspace.fragstotal, dspspace.fragsize, dspspace.bytes);
 
-/* input queue empty and output buffer with less than one fragment to play */
-if (!wwo->lpPlayPtr && wwo->dwBufferSize < availInQ + wwo->dwFragmentSize) {
+/* input queue empty and output buffer with less than one fragment to play 
+ * actually some cards do not play the fragment before the last if this one is partially feed
+ * so we need to test for full the availability of 2 fragments
+ */
+if (!wwo->lpPlayPtr && wwo->dwBufferSize < availInQ + 2 * wwo->dwFragmentSize && 
+!wwo->bNeedPost) {
 	TRACE("Run out of wavehdr:s...\n");
 return INFINITE;
 }
@@ -1216,8 +1244,8 @@
 		TRACE("flushing\n");
 		ioctl(wwo->ossdev->fd, SNDCTL_DSP_SYNC, 0);
 		wwo->dwPlayedTotal = wwo->dwWrittenTotal;
-		}
-		else {
+dwNextNotifyTime = wodPlayer_NotifyCompletions(wwo, FALSE);
+		} else {
 		TRACE("recovering\n");
 		dwNextFeedTime = wodPlayer_FeedDSP(wwo);
 		}







Re: W2K results from the current tests

2002-12-11 Thread Jeff Smith
From: Tony Lambregts <[EMAIL PROTECTED]>



runtests.bat>>result.txt 2>&1  does not work on Windows 98 and it is not 
likely to work on any Win9x.


I wondered if the problem was output going to stderr.  I had not had
a chance to take a good look at it.  Is there anyway to tell the *test
programs* (i.e. not the script) to send output elsewhere, such as
stdout?  If not it should be added.  Then piping to a file should work
without any special incantations in Windows.  This is significant to me
now, as I am taking up Win98SE testing.


Is there any reason that I should not put a patch together that changes the 
calls to stderr to stdout?

--

Tony Lambregts






RE: Wine, Windows.Forms on Linux, GC and segfaults.

2002-12-11 Thread Patrik Stridvall
> > So please try again without linking with -lpthread.
> 
> The problem is that this is very hard for us to do as two of the
> underlying libraries we are using (libmono and libgc) both 
> link against
> pthread to achieve their threading capabilities.

Sure, however Winelib provides a pthread implementation so it should
be possible to get it to work anyway. It currently works for OpenGL so
I can't see why it can't work for libmono and libgc. Sure our pthread
implementation might need some improvements but it should work in 
theory.

Just remove -lpthread from the linking command line and see what happends.
If you get errors about unimplemented functions it is probably because 
Wine's pthread implementation doesn't implement that function yet.

> It might be better to investigate what are Wine's requirements for
> having its own pthread implementation, and have those changed 
> pushed to
> the maintainers of pthreads.

In the long term possibly. However we need a platform independent
solution which at minimum supports Linux, *BSD and Solaris.

> In particular, we are interested in using WineLib, maybe it would be
> possible to have WineLib use the standard pthread 
> implementation instead
> of rolling its own?

Well, Winelib uses pthreads on non-x86 platforms, so I guess it would
be possible to do it on x86 as well. However Wine, the emulator part
can't possible work with pthreads because it needs more control than
pthread provides.

In any case, I don't see any reasonable short term solution than to
improve Wine's pthread implementation to support libmono and libgc.
If you are lucky it might work right away. Fingers crossed. :-)




Wine conformance testing on native platforms

2002-12-11 Thread Luke Stras
Dimi, I see that you've added me as a "volunteer" for running the
conformance tests on NT.  Gee, thanks :).

In any case, I don't mind doing this.  However, I have a question : what
should I do with the test results?  Posting them to wine-devel every
time a test changes seems somewhat high-bandwidth...

What we (i.e., the testers) could do is to keep track of what changes
between successive test runs, I guess, and we could just post a summary
of the changes.

This brings up another point: these test results should be put up
somewhere on the Web for everyone to see.  Might I suggest putting them
up on the Wine Janitorial Projects page?  For every platform, just put
in a link to "Most recent test results", say.

One last thing: is there any way to be automatically notified whenever
the available test suite changes?

-- 
Luke Stras <[EMAIL PROTECTED]>
"The meek can have the Earth; the rest of us have other plans" 
  --Henry Spencer




Re: winelib + unicode

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 12:05 pm, Martin Wilck wrote:
> I can't follow you. Winemaker generates a configure.ac file. You need to
> run autoconf and configure anyway to build your code.
> We just need to make sure that Winemaker puts a test for -fshort-wchar
> into configure.ac.
>
> What am I missing?

Nothing. I forgot that winemaker generates a configure.ac file as well. :)
So yeah, a test in there would be good, if it fails we should report an
error. If someone really needs to use the other hacks, they can just edit
the configure.ac to take the test out.

-- 
Dimi.





Re: [patch] revert part of Aug 26 change in winmm/wineoss/audio.cthat broke msvc++4.0 installer?

2002-12-11 Thread Dan Kegel
Dimitrie O. Paun wrote:

On December 11, 2002 02:20 am, Dan Kegel wrote:


 /* input queue empty and output buffer with less than one fragment to play */
-if (!wwo->lpPlayPtr && wwo->dwBufferSize < availInQ + wwo->dwFragmentSize) { 
-   TRACE("Run out of wavehdr:s...\n");
+if (!wwo->lpPlayPtr && wwo->dwBufferSize < availInQ + 2 * wwo->dwFragmentSize) {
+TRACE("Run out of wavehdr:s... flushing (%lu => %lu)\n",
+  wwo->dwPlayedTotal, wwo->dwWrittenTotal);
+wwo->dwPlayedTotal = wwo->dwWrittenTotal;
 return INFINITE;
 }
Can someone who understands the code comment?


I don't, never looked at audio code before, but the above has two changes:

The condition has the '2 *' bit in it, and the body of the if has
+wwo->dwPlayedTotal = wwo->dwWrittenTotal;
The TRACEs are noops, can be ignored.

So I suggest trying them out individually, to see which one
causes the problem (or maybe they can not be separated). 
Experimentation will tell. :)

I tried each individually, and neither helped.  Only the two
changes together yielded a wine that properly terminated
when I clicked on the "Exit" button in msvc4++'s installer.
- Dan







RE: W2K results from the current tests

2002-12-11 Thread Jeff Smith
From: "Rolf Kalbermatter" <[EMAIL PROTECTED]>

W2K results from the current tests as downloaded from 
http://fgouget.free.fr/wine/winetests.zip

They seem to match the WinXP tests mostly ;-).

Just one remark. The tests output all there results on stderr so to 
redirect
all info into a file when starting the batch file the command

runtests.bat>>result.txt 2>&1

seems very useful. This may not work on Win9x command prompts but it does 
on
W2K and XP.

I wondered if the problem was output going to stderr.  I had not had
a chance to take a good look at it.  Is there anyway to tell the *test
programs* (i.e. not the script) to send output elsewhere, such as
stdout?  If not it should be added.  Then piping to a file should work
without any special incantations in Windows.  This is significant to me
now, as I am taking up Win98SE testing.

-- Jeff S


_
Add photos to your messages with MSN 8. Get 2 months FREE*. 
http://join.msn.com/?page=features/featuredemail




Re: winelib + unicode

2002-12-11 Thread Martin Wilck
Am Mit, 2002-12-11 um 16.49 schrieb Dimitrie O. Paun:

> On December 11, 2002 10:52 am, Martin Wilck wrote:
> > well the configure script should probably check if -fshort-wchar is
> > supported, add the option to CFLAGS if yes, and issue a warning if no.
> 
> But the problem is that winemaker will run on different systems that
> configure runs on... It will get it mostly right, but now always.

I can't follow you. Winemaker generates a configure.ac file. You need to
run autoconf and configure anyway to build your code.
We just need to make sure that Winemaker puts a test for -fshort-wchar 
into configure.ac.

What am I missing?

Martin

-- 
Martin WilckPhone: +49 5251 8 15113
Fujitsu Siemens Computers   Fax:   +49 5251 8 20409
Heinz-Nixdorf-Ring 1mailto:[EMAIL PROTECTED]
D-33106 Paderborn   http://www.fujitsu-siemens.com/primergy









Re: Conformance tests on WinNT

2002-12-11 Thread Michael Stefaniuc
On Wed, Dec 11, 2002 at 09:24:25AM -0600, Jeff Smith wrote:
> You don't have anyone for Win95?  I figured you did.
> *If* no one else will, I can do this one too,
> as my linux box is dual boot w/ Win95-OSR2.1 I believe.
> But if anyone else will take this on, please do, as
> this box is the Internet gateway for my family. :-/
I have an old box with the first version of Win95 at home and that box
is only catching dust. That means i could take ownership for Win95.

bye
michael

> >On December 11, 2002 09:14 am, Tom Wickline wrote:
> > > Were down to ( _1_ ) Win98SE Anyone ??
> >
> >And what about Win95?

-- 
Michael Stefaniuc   Tel.: +49-711-96437-199
System Administration   Fax.: +49-711-96437-111
Red Hat GmbHEmail: [EMAIL PROTECTED]
Hauptstaetterstr. 58http://www.redhat.de/
D-70178 Stuttgart



msg15352/pgp0.pgp
Description: PGP signature


Re: Conformance tests on WinNT

2002-12-11 Thread Fabian Cenedese


You don't have anyone for Win95?  I figured you did.
*If* no one else will, I can do this one too,
as my linux box is dual boot w/ Win95-OSR2.1 I believe.
But if anyone else will take this on, please do, as
this box is the Internet gateway for my family. :-/


I could at least try, I also have a second computer, like P90 or so.
It's just used for burning CDs while I can continue working on the other.
I'm not sure about the Win95 version, but I will have a look and try this
evening.

bye  Fabi







Re: WinXP Test Oddities (Changed Test Results!!)

2002-12-11 Thread Dave
Ok, I've rebooted and done advapi32_test.exe registry again.  It now seems 
to hand halfway through the test.  Here is the output on WinXP Pro:

C:\winetests>advapi32_test.exe registry
registry.c:80: Test failed: data_count set to 24 instead of 7
registry.c:81: Test failed: type 2 is not REG_SZ
registry.c:94: Test failed: data_count set to 24 instead of 7
registry.c:95: Test failed: type 2 is not REG_SZ
registry.c:96: Test failed: value set to 'xx' instead of 'Te'
registry.c:97: Test failed: data set to 'xx' instead of 'foobar'
registry.c:108: Test failed: data_count set to 24 instead of 7
registry.c:109: Test failed: type 2 is not REG_SZ
registry.c:111: Test failed: data set to 'xx' instead of 'foobar'
registry.c:122: Test failed: data_count set to 24 instead of 7
registry.c:123: Test failed: type 2 is not REG_SZ
registry.c:134: Test failed: expected ERROR_SUCCESS, got 234
registry.c:135: Test failed: val_count set to 20 instead of 4
registry.c:136: Test failed: data_count set to 24 instead of 7
registry.c:137: Test failed: type 2 is not REG_SZ
registry.c:138: Test failed: value is 'xx' instead of Test
registry.c:139: Test failed: data is 'xx' instead of foobar
registry.c:155: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:156: Test failed: type 2 is not REG_SZ
registry.c:169: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:170: Test failed: type 2 is not REG_SZ
registry.c:182: Test failed: val_count set to 5 instead of 4
registry.c:183: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:184: Test failed: type 2 is not REG_SZ
registry.c:185: Test failed: value is not 'Test'
registry.c:195: Test failed: expected ERROR_SUCCESS, got 234
registry.c:196: Test failed: val_count set to 5 instead of 4
registry.c:197: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:198: Test failed: type 2 is not REG_SZ
registry.c:199: Test failed: value is not 'Test'
registry.c:200: Test failed: data is not 'foobar'

At this point it seems to stop responding and advapi32_test.exe is eating 
99% CPU.  Of course it could be my system that is in error.

I then ran the tests on my laptop, running WinXP home edition.  I receive 
only 3 errors there.  The output follows.

C:\winetests>advapi32_test.exe registry
registry.c:96: Test failed: value set to 'xx' instead of 'Te'
registry.c:97: Test failed: data set to 'xxx' instead of 'foobar'
registry.c:111: Test failed: data set to 'xxx' instead of 'foobar'
registry: 56 tests executed, 0 marked as todo, 3 failures.

Note that I downloaded new test binaries for these tests after finding the 
test hung on WinXP Pro.  This did not seem to have any effect on the results.

At 05:39 PM 12/11/2002 +1100, you wrote:
Hi,

I ran the advapi32_test registry again today, and only received 3
errors:

h:\wine\wine\dlls\advapi32\tests\registry.c:96: Test failed: value set
to 'xx' instead of 'Te'
h:\wine\wine\dlls\advapi32\tests\registry.c:97: Test failed: data set to
'xxx' instead of 'foobar'
h:\wine\wine\dlls\advapi32\tests\registry.c:111: Test failed: data set
to 'xxx' instead of 'foobar'

This seems very strange to me. I ran the test at first because I thought
it might have been a matter of long file names, but then when I moved it
back I found it wasn't, there was just something weird happening
instead.

I'll try to reproduce the other errors tonight if I can, and if I am
successful I will post the results to the wine-devel group.

David Miller, you also received 31 errors for this test, yes? Could you
test again straight after a computer reboot?

Thanks,
Kye Lewis


You can reach me at:
[EMAIL PROTECTED] at most times
[EMAIL PROTECTED] from 9am to 3pm Monday to Friday
[EMAIL PROTECTED] is an alternative email







Re: winelib + unicode

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 10:52 am, Martin Wilck wrote:
> well the configure script should probably check if -fshort-wchar is
> supported, add the option to CFLAGS if yes, and issue a warning if no.

But the problem is that winemaker will run on different systems that
configure runs on... It will get it mostly right, but now always.
However, my comment was referring to this bit:
http://www.winehq.org/Docs/winelib-user/unicode.shtml
It makes things look complicated. It should be: 
  "Use a gcc that support -fshort-wchar (2.9.7 or later)"

Instead, we present 3 options as if they are *equally* likely/desirable,
and then we let the poor developer not familiar with the problem to
agonize over which option to use. In reality, 1. is likely used in 
99.999% of case, the others are clever hacks that are maybe interesting 
for historical reasons nowadays.

I think we should try to make the documentation concise, not long.
Most people think that the quality of documentation is measured in
pages. Often times, is inversely proportional. Let's try to document
a preferred way of doing things (maybe present some options when they
are equally likely).

That being said, I want to stress that this is a minor nit, and that
I actually like our documentation (incomplete as it is). I just picked
it up as an excuse for my daily rant... :)

-- 
Dimi.





RE: W2K results from the current tests

2002-12-11 Thread Rolf Kalbermatter
W2K results from the current tests as downloaded from 
http://fgouget.free.fr/wine/winetests.zip

They seem to match the WinXP tests mostly ;-).

Just one remark. The tests output all there results on stderr so to redirect
all info into a file when starting the batch file the command 

runtests.bat>>result.txt 2>&1

seems very useful. This may not work on Win9x command prompts but it does on
W2K and XP.


D:\CVS\wine\tests>advapi32_test.exe registry 
registry: 56 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>dsound_test.exe dsound 
dsound.c:56:Testing Primary Sound Driver - 
dsound.c:70:  DirectSound Caps: flags=0x0b5b secondary min=7200 max=48000
dsound.c:100:  PrimaryBuffer Caps: flags=0x0009 size=32768
dsound.c:113:  tag=0x0001 22050x8x2 avg.B/s=44100 align=2
dsound.c:129:  status=0x
dsound.c:56:Testing Crystal WDM Audio - cwawdm.sys
dsound.c:70:  DirectSound Caps: flags=0x0b5b secondary min=7200 max=48000
dsound.c:100:  PrimaryBuffer Caps: flags=0x0009 size=32768
dsound.c:113:  tag=0x0001 22050x8x2 avg.B/s=44100 align=2
dsound.c:129:  status=0x
dsound: 27 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe alloc 
alloc: 58 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe atom 
atom: 229398 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe codepage 
codepage: 2 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe directory 
directory: 51 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe drive 
drive: 162 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe environ 
environ: 39 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe file 
file.c:633:Current offset = 0015
file.c:658:Current offset = 0015
file: 487239 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe format_msg 
format_msg: 58 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe locale 
locale: 54 tests executed, 0 marked as todo, 0 failures.

D:\CVS\wine\tests>kernel32_test.exe path 
path.c:514: Test failed: GetLongPathNameA: wrong return code, 96 instead of 41
path.c:252: Test failed: check-1: GetShortPathNameA error: len=0 error=123 
tmpstr=[<ü]

path.c:277: Test failed: check-1: GetLongPathA returned 123 and not 2
path.c:252: Test failed: check-2: GetShortPathNameA error: len=0 error=123 
tmpstr=[<ü]

path.c:277: Test failed: check-2: GetLongPathA returned 123 and not 2
path.c:252: Test failed: check-4: GetShortPathNameA error: len=0 error=123 
tmpstr=[<ü]

path.c:277: Test failed: check-4: GetLongPathA returned 123 and not 2
path.c:252: Test failed: check-5: GetShortPathNameA error: len=0 error=123 
tmpstr=[<ü]

path.c:277: Test failed: check-5: GetLongPathA returned 123 and not 2
path.c:889:TMP=C:\DOCUME~1\Rolf\LOCALS~1\Temp
path.c:900:TMP=C:\WINNT
path.c:910:TMP=C:\
path.c:920:TMP=C:
path: 1800 tests executed, 0 marked as todo, 9 failures.

D:\CVS\wine\tests>kernel32_test.exe process 
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
tests/process.c: 1 tests executed, 0 marked as todo, 0 failures.
process.c:376: Test failed: StartupInfoA:lpDesktop expected (null), got 
WinSta0\Defaul

Re: Conformance tests on WinNT

2002-12-11 Thread Tom Wickline
Jeff Smith wrote:

You don't have anyone for Win95?  I figured you did.
*If* no one else will, I can do this one too,
as my linux box is dual boot w/ Win95-OSR2.1 I believe.
But if anyone else will take this on, please do, as
this box is the Internet gateway for my family. :-/


Here is the First E-Mail on this subject


---

The conformance tests need you!

From: Francois Gouget ([EMAIL PROTECTED])
Date: Fri Nov 29 2002 - 21:02:39 CST



Hi,


I have been running the Wine conformance tests on Windows 95 and NT4.
The results are pretty bad. 24 tests out of 32 have failures in one or
more of these two platforms.

That's 75% of 'Windows conformance tests' that don't work on Windows!
Out of the 32 tests, only 4, that's 12.5%, execute successfully on all
tested platforms (and one of them has 4 todos in Wine).

You can see things more graphically at the following URL:
http://fgouget.free.fr/wine/tests-en.shtml

Come on people, we can do better.
Send fixes to wine-patches, and send me emails to so that I update this
table.

--

Tom





Re: winelib + unicode

2002-12-11 Thread Martin Wilck
Am Mit, 2002-12-11 um 16.17 schrieb Dimitrie O. Paun:

> The -fshort-wchar is the only correct fix to the problem, and just
> by enumerating the other hacks we just confuse the issue. 

Agreed - at least I see no need for automating them.

> Who is crazy enough to use the other hacks where there is such a
> simple (and correct) fix available? This option is probably supported
> nowadays by most gcc installations, and for the 1 in 1000 that doesn't
> want to use it (for whatever reason), they will bring it up on wine-devel
> and they'll get an answer. No point in cluttering the documentation
> (Winelib User's Guide), the scripts (winemaker), etc. with them.

well the configure script should probably check if -fshort-wchar is
supported, add the option to CFLAGS if yes, and issue a warning if no.

Martin

-- 
Martin WilckPhone: +49 5251 8 15113
Fujitsu Siemens Computers   Fax:   +49 5251 8 20409
Heinz-Nixdorf-Ring 1mailto:[EMAIL PROTECTED]
D-33106 Paderborn   http://www.fujitsu-siemens.com/primergy









Re: Conformance tests on WinNT

2002-12-11 Thread Tom Wickline
Jeff Smith wrote:

1.) One of the computers at my home has Win98SE.
2.) I will probably have to run precompiled tests.
3.) I do not know how often I can run the tests.
4.) It will probably be a couple of days before I can get to it.

Within those limits, I would be glad to do the 98SE tests.

On the matter of redirection, redir to NUL works fine, but not to
a file, although it should.  So maybe if I can redirect to a device,
and somehow redirect the device to a file?

I have other ideas on the (lack of) redirection to a file issue, but
again, it may be a couple of days before I can do much testing on it.

-- Jeff S


Great...


Dimi can you add Jeff to the page  for Win98SE ?

Tom





Re: winelib + unicode

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 08:13 am, Martin Wilck wrote:
> wouldn't it be nice to have winemaker-generated sources automatically
> add "-fshort-wchar" to the C compiler options?

I personally don't understand why we even bother with other options.
The -fshort-wchar is the only correct fix to the problem, and just
by enumerating the other hacks we just confuse the issue. 

Who is crazy enough to use the other hacks where there is such a
simple (and correct) fix available? This option is probably supported
nowadays by most gcc installations, and for the 1 in 1000 that doesn't
want to use it (for whatever reason), they will bring it up on wine-devel
and they'll get an answer. No point in cluttering the documentation
(Winelib User's Guide), the scripts (winemaker), etc. with them.

-- 
Dimi.





Re: SafeDisc 2 support ?

2002-12-11 Thread Rizsanyi Zsolt
On Wednesday 11 December 2002 16:03, Steven Edwards wrote:
> Here is the patch. it needs to be updated for the current cvs
>
> http://www.winehq.com/hypermail/wine-patches/2002/04/0194.html

I have sent an updated patch to wine-devel recently. That should be pretty 
close to current cvs. (Or I can do a cvs diff if somebody needed)

> --- Zsolt Rizsanyi <[EMAIL PROTECTED]> wrote:
> > On Wednesday 11 December 2002 15:04, Steven Edwards wrote:
> > > --- Tom Wickline <[EMAIL PROTECTED]> wrote:
> > > > Does Current wine support SafeDisc 2 ?
> > > > If not when will it ?
> > >
> > > There were some patches for a SafeDisc driver that might violate the
> > > DMCA so they were never accepted and if I remeber right it didnt
> > > support SD2.
> >
> > It very probably does not violate DMCA, but 'only' copyright. So with a
> > clean room implementation there is a chance that it will be included. At
> > least this was conclusion from the last discussion.
> >
> > And yes it did not support SD2. Tough it should be not hard to implement
> > support, if you have a program with SD2. If you are interested, then you
> > should look at list archives and all the threads where Laurent Pinchart
> > participated. AFAIK he was only working on this and related issues in
> > wine.
> >
> > You can use Google's advanced search option to search the archives (by
> > specifying the site.)
> >
> > Regards
> > Zsolt




Re: Conformance tests on WinNT

2002-12-11 Thread Jeff Smith
You don't have anyone for Win95?  I figured you did.
*If* no one else will, I can do this one too,
as my linux box is dual boot w/ Win95-OSR2.1 I believe.
But if anyone else will take this on, please do, as
this box is the Internet gateway for my family. :-/


On December 11, 2002 09:14 am, Tom Wickline wrote:
> Were down to ( _1_ ) Win98SE Anyone ??

And what about Win95?

--
Dimi.



_
Add photos to your e-mail with MSN 8. Get 2 months FREE*. 
http://join.msn.com/?page=features/featuredemail




Re: Conformance tests on WinNT

2002-12-11 Thread Jeff Smith
1.) One of the computers at my home has Win98SE.
2.) I will probably have to run precompiled tests.
3.) I do not know how often I can run the tests.
4.) It will probably be a couple of days before I can get to it.

Within those limits, I would be glad to do the 98SE tests.

On the matter of redirection, redir to NUL works fine, but not to
a file, although it should.  So maybe if I can redirect to a device,
and somehow redirect the device to a file?

I have other ideas on the (lack of) redirection to a file issue, but
again, it may be a couple of days before I can do much testing on it.

-- Jeff S



From: Tom Wickline <[EMAIL PROTECTED]>

James K Whiting wrote:

I don't think that anyone's posted the results of the conformance tests
as run on NT.


There has been no post on 98SE and ME..
Anyone want to Volinteer ??

Francos has made it verry simple to do :))

Tom



I have access to Windows ME. Where are the tests and instructions?

James



Great .. I see Tony has already sent the Info.
And Dimi has added you to the list of testers.

Were down to ( _1_ ) Win98SE Anyone ??

Tom



_
MSN 8 with e-mail virus protection service: 2 months FREE* 
http://join.msn.com/?page=features/virus




Re: window(statusbar) position bug

2002-12-11 Thread Lionel Ulmer
On Wed, Dec 11, 2002 at 12:49:47AM -0500, Chris Morgan wrote:
> Under managed mode starcrafts editor the status bar appears in the incorrect 
> location, some 1 inch from the bottom of the maximized window(the way the 
> editor starts up).  The same behavior occurs in non-managed mode although the 
> status bar is in the correct location whenever the window isn't maximized.  
> Any ideas?  Alexandre?  I wouldn't mind looking into this but I'm not very 
> familiar with how wine/windows handles resizing and where to begin looking.

I once had a problem similar and it was related to the 'Start' bar at the
bottom of the screen (ie is the screen Y dimension returned WITH or WITHOUT
the number of pixels used by this bar).

It may be another problem though.

 Lionel

-- 
 Lionel Ulmer - http://www.bbrox.org/




OT - Re: PATCH: more tmarshal

2002-12-11 Thread Steven Edwards
Hola,
would it be possible to seperate the typelib code required for oleaut32? I have been 
looking at
seperating out ole2dsp and typelib from oleaut32 so we can properly build under mingw 
but I dont
know enough about it. 

Thanks
Steven

--- Marcus Meissner <[EMAIL PROTECTED]> wrote:
> Hi,
> 
> VT_USERDEFINED in turn can contain any 'normal' type, so serialize/deserialize
> all types. Spotted by Excel Macro Recorder.
> 
> Ciao, Marcus
> 
> Changelog:
>   Serialize/deserialize all reftypes in VT_USERDEFINED.


__
Do you Yahoo!?
Yahoo! Mail Plus - Powerful. Affordable. Sign up now.
http://mailplus.yahoo.com




Re: Stretch Drawing

2002-12-11 Thread Lionel Ulmer
On Wed, Dec 11, 2002 at 08:50:24AM +, Mike Hearn wrote:
> I think XV (xvideo) might have stuff for hardware scaling, it might be
> worth asking on the xpert list. I was talking to somebody the other
> night who reckoned Director was 4x slower under Wine than Windows,
> potentially because Director thought it couldn't use hardware
> acceleration and was doing all the rendering in software?

Well, Xv certainly supports hardware scaling... But AFAIK only the NVIDIA
binary driver advertizes an RGB pixel format (last time I checked, on G400
or Radeon, you only had YUV pixel formats supported by Xv).

If you speak about video scaling (and not bitmap scaling), that's of course
a whole other story :-)

 Lionel

-- 
 Lionel Ulmer - http://www.bbrox.org/




Re: Conformance tests on WinNT

2002-12-11 Thread Dimitrie O. Paun
On December 11, 2002 09:14 am, Tom Wickline wrote:
> Were down to ( _1_ ) Win98SE Anyone ??

And what about Win95?

-- 
Dimi.





Re: SafeDisc 2 support ?

2002-12-11 Thread Steven Edwards
Here is the patch. it needs to be updated for the current cvs 

http://www.winehq.com/hypermail/wine-patches/2002/04/0194.html

--- Zsolt Rizsanyi <[EMAIL PROTECTED]> wrote:
> On Wednesday 11 December 2002 15:04, Steven Edwards wrote:
> > --- Tom Wickline <[EMAIL PROTECTED]> wrote:
> > > Does Current wine support SafeDisc 2 ?
> > > If not when will it ?
> >
> > There were some patches for a SafeDisc driver that might violate the DMCA
> > so they were never accepted and if I remeber right it didnt support SD2.
> 
> It very probably does not violate DMCA, but 'only' copyright. So with a clean 
> room implementation there is a chance that it will be included. At least this 
> was conclusion from the last discussion.
> 
> And yes it did not support SD2. Tough it should be not hard to implement 
> support, if you have a program with SD2. If you are interested, then you 
> should look at list archives and all the threads where Laurent Pinchart 
> participated. AFAIK he was only working on this and related issues in wine.
> 
> You can use Google's advanced search option to search the archives (by 
> specifying the site.)
> 
> Regards
> Zsolt
> 


__
Do you Yahoo!?
Yahoo! Mail Plus - Powerful. Affordable. Sign up now.
http://mailplus.yahoo.com




Re: WinXP Test Oddities (Changed Test Results!!)

2002-12-11 Thread David Miller
Sorry if this appears on the list twice.  I sent from the wrong address 
the  first time and messages seem to not appear on wine-devel unless I send 
from the address I have subscribed.

Ok, I've rebooted and done advapi32_test.exe registry again.  It now seems 
to hand halfway through the test.  Here is the output on WinXP Pro:

C:\winetests>advapi32_test.exe registry
registry.c:80: Test failed: data_count set to 24 instead of 7
registry.c:81: Test failed: type 2 is not REG_SZ
registry.c:94: Test failed: data_count set to 24 instead of 7
registry.c:95: Test failed: type 2 is not REG_SZ
registry.c:96: Test failed: value set to 'xx' instead of 'Te'
registry.c:97: Test failed: data set to 'xx' instead of 'foobar'
registry.c:108: Test failed: data_count set to 24 instead of 7
registry.c:109: Test failed: type 2 is not REG_SZ
registry.c:111: Test failed: data set to 'xx' instead of 'foobar'
registry.c:122: Test failed: data_count set to 24 instead of 7
registry.c:123: Test failed: type 2 is not REG_SZ
registry.c:134: Test failed: expected ERROR_SUCCESS, got 234
registry.c:135: Test failed: val_count set to 20 instead of 4
registry.c:136: Test failed: data_count set to 24 instead of 7
registry.c:137: Test failed: type 2 is not REG_SZ
registry.c:138: Test failed: value is 'xx' instead of Test
registry.c:139: Test failed: data is 'xx' instead of foobar
registry.c:155: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:156: Test failed: type 2 is not REG_SZ
registry.c:169: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:170: Test failed: type 2 is not REG_SZ
registry.c:182: Test failed: val_count set to 5 instead of 4
registry.c:183: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:184: Test failed: type 2 is not REG_SZ
registry.c:185: Test failed: value is not 'Test'
registry.c:195: Test failed: expected ERROR_SUCCESS, got 234
registry.c:196: Test failed: val_count set to 5 instead of 4
registry.c:197: Test failed: data_count set to 48 instead of 7*sizeof(WCHAR)
registry.c:198: Test failed: type 2 is not REG_SZ
registry.c:199: Test failed: value is not 'Test'
registry.c:200: Test failed: data is not 'foobar'

At this point it seems to stop responding and advapi32_test.exe is eating 
99% CPU.  Of course it could be my system that is in error.

I then ran the tests on my laptop, running WinXP home edition.  I receive 
only 3 errors there.  The output follows.

C:\winetests>advapi32_test.exe registry
registry.c:96: Test failed: value set to 'xx' instead of 'Te'
registry.c:97: Test failed: data set to 'xxx' instead of 'foobar'
registry.c:111: Test failed: data set to 'xxx' instead of 'foobar'
registry: 56 tests executed, 0 marked as todo, 3 failures.

Note that I downloaded new test binaries for these tests after finding the 
test hung on WinXP Pro.  This did not seem to have any effect on the results.

At 05:39 PM 12/11/2002 +1100, you wrote:
Hi,

I ran the advapi32_test registry again today, and only received 3
errors:

h:\wine\wine\dlls\advapi32\tests\registry.c:96: Test failed: value set
to 'xx' instead of 'Te'
h:\wine\wine\dlls\advapi32\tests\registry.c:97: Test failed: data set to
'xxx' instead of 'foobar'
h:\wine\wine\dlls\advapi32\tests\registry.c:111: Test failed: data set
to 'xxx' instead of 'foobar'

This seems very strange to me. I ran the test at first because I thought
it might have been a matter of long file names, but then when I moved it
back I found it wasn't, there was just something weird happening
instead.

I'll try to reproduce the other errors tonight if I can, and if I am
successful I will post the results to the wine-devel group.

David Miller, you also received 31 errors for this test, yes? Could you
test again straight after a computer reboot?

Thanks,
Kye Lewis


You can reach me at:
[EMAIL PROTECTED] at most times
[EMAIL PROTECTED] from 9am to 3pm Monday to Friday
[EMAIL PROTECTED] is an alternative email






RE: SafeDisc 2 support ?

2002-12-11 Thread Patrik Stridvall
> --- Tom Wickline <[EMAIL PROTECTED]> wrote:
> > Does Current wine support SafeDisc 2 ?
> > If not when will it ?
> 
> There were some patches for a SafeDisc driver that might 
> violate the DMCA so they were never
> accepted and if I remeber right it didnt support SD2.

Correct, it didn't support SafeDisc 2. However I
think that at least part of it was accepted. Anyway the
reason that some part was not not accepted was not 
DMCA related.

What the DMCA says is bad enough however there is no
reason to claim that the DMCA says thing that it doesn't.

Any implementation of SafeDisc in Wine would not be
PRIMARILY designed as a circumvention device through any
remotely reasonable definition of circumvention device
and in addition to that PRIMARILY designed needs to be
proven as well.

SafeDisc simply tries to assure that the CD in the
drive is not a copy. Nothing more, nothing less.

Please people, don't let DMCA paranoia reach new heights.




Re: SafeDisc 2 support ?

2002-12-11 Thread Zsolt Rizsanyi
On Wednesday 11 December 2002 15:04, Steven Edwards wrote:
> --- Tom Wickline <[EMAIL PROTECTED]> wrote:
> > Does Current wine support SafeDisc 2 ?
> > If not when will it ?
>
> There were some patches for a SafeDisc driver that might violate the DMCA
> so they were never accepted and if I remeber right it didnt support SD2.

It very probably does not violate DMCA, but 'only' copyright. So with a clean 
room implementation there is a chance that it will be included. At least this 
was conclusion from the last discussion.

And yes it did not support SD2. Tough it should be not hard to implement 
support, if you have a program with SD2. If you are interested, then you 
should look at list archives and all the threads where Laurent Pinchart 
participated. AFAIK he was only working on this and related issues in wine.

You can use Google's advanced search option to search the archives (by 
specifying the site.)

Regards
Zsolt




Re: SafeDisc 2 support ?

2002-12-11 Thread Steven Edwards
--- Tom Wickline <[EMAIL PROTECTED]> wrote:
> Does Current wine support SafeDisc 2 ?
> If not when will it ?

There were some patches for a SafeDisc driver that might violate the DMCA so they were 
never
accepted and if I remeber right it didnt support SD2.

__
Do you Yahoo!?
Yahoo! Mail Plus - Powerful. Affordable. Sign up now.
http://mailplus.yahoo.com




Re: Conformance tests on WinNT

2002-12-11 Thread Tom Wickline
James K Whiting wrote:

I don't think that anyone's posted the results of the conformance tests
as run on NT.


There has been no post on 98SE and ME..
Anyone want to Volinteer ??

Francos has made it verry simple to do :))

Tom



I have access to Windows ME. Where are the tests and instructions?

James



Great .. I see Tony has already sent the Info.
And Dimi has added you to the list of testers.

Were down to ( _1_ ) Win98SE Anyone ??

Tom





SafeDisc 2 support ?

2002-12-11 Thread Tom Wickline
Does Current wine support SafeDisc 2 ?
If not when will it ?

Tom





Re: Wine, Windows.Forms on Linux, GC and segfaults.

2002-12-11 Thread Marcus Meissner
On Tue, Dec 10, 2002 at 08:41:34PM -0500, Miguel de Icaza wrote:
> Hello,
> 
> With the help of Hans Boehm, I have been tracking the problems we
> have to run the Windows.Forms code with GC enabled.  Turns out that the
> problem is not the Boehm code at all, it just exposes a problem that
> might be happening elsewhere.
> 
> The problem is that by the time that Wine has been initialized,
> using setjmp/longjmp will always lead to a crash.  The code in pthreads
> that performs the longjmp will first try to invoke the pthread cleanup
> routines, and then invoke longjmp.  This never happens.
> 
> In the particular case of Mono, I added a small bit of code before
> calling into Boehm's GC, and then I run my app like this:
> 
>   wine monostub.exe.so 
> 
>  The code snippet is:
> 
>   jmp_buf buf;
>   
>   printf ("Here\n");
>   if (setjmp (buf) == 0){
>   printf ("before\n");
>   longjmp (buf, 1);
>   } else {
>   printf ("after\n"); 
>   }
> 
>  The code should display:
> 
>   Here
>   before
>   after
> 
>   But with Wine, I get a crash inside longjmp, after the "before" is
> printed out.  I get the Wine Console with the stack trace, but I can not
> copy/paste from it, so I have included a screenshot of it.

You currently cannot use the wine libraries together with -lpthread.

WINE already overwrites and reimplements several pthread_ functions
which probably leads to internal confusion and the crash above.

Difficult to solve :/

Ciao, Marcus




RE: Wine, Windows.Forms on Linux, GC and segfaults.

2002-12-11 Thread Patrik Stridvall
> The problem is that by the time that Wine has been initialized,
> using setjmp/longjmp will always lead to a crash.  The code 
> in pthreads
> that performs the longjmp will first try to invoke the pthread cleanup
> routines, and then invoke longjmp.  This never happens.

You can't and needn't link with -lpthread. Wine has its own
pthread implmentation.

I tried your included code and it works just fine unless you
link with -lpthread, then it crashes in the same way as in your
attached picture. But then you should never link Wine with
-lpthread so that is not really a bug.

Of course Wine pthread implementation it not in any way complete
so some function might be missing and some might only be only
partially implemented and of course some might be incorrectly
implemented.

So please try again without linking with -lpthread.




winelib + unicode

2002-12-11 Thread Martin Wilck

wouldn't it be nice to have winemaker-generated sources automatically
add "-fshort-wchar" to the C compiler options?

To make this robust, one could write a configure test for it.
Martin

-- 
Martin WilckPhone: +49 5251 8 15113
Fujitsu Siemens Computers   Fax:   +49 5251 8 20409
Heinz-Nixdorf-Ring 1mailto:[EMAIL PROTECTED]
D-33106 Paderborn   http://www.fujitsu-siemens.com/primergy









Re: Wine, Windows.Forms on Linux, GC and segfaults.

2002-12-11 Thread Steven Edwards
>   I was wondering if it would be possible to just "link" against the
> Wine library instead of having to create a stub application to run from?

The way linking works in winelib is kinda odd with the usage of the *.spec that it 
seems this is
not possible. There was some disscussion on this a while back and certain changes that 
would be
needed to LD but I think those might also have been for PE support. If I remember 
right this has
something to do not only with LD but with alot of the magic wineserver works and hence 
just
linking your application to a winelib library would not include all of the support 
wineserver
provides. The rule seems to be its impossible to just -lwine your application. Wine is 
approaching
0.9 soon so once we hit 1.x then we should have a stable ABI/API which will make 
sharing the dlls
a lot easyer if you come up with a new loading/linking method for mono rather then the 
winebuild
system and its more interesting "features"

Thanks
Steven 

__
Do you Yahoo!?
Yahoo! Mail Plus - Powerful. Affordable. Sign up now.
http://mailplus.yahoo.com




wineoss/wavemap and i810 sound cards

2002-12-11 Thread Francois Gouget

Here's the problem: apparently i810 sound cards (and the corresponding 
OSS drivers) only accept 48kHz sound in 16 bit stereo. So if an 
application uses winmm to play a sound in any other format, winmm has to 
use the wave mapper to do the conversion to that format.

But msacm refuses to do a conversion to 48kHz sound because that 
sampling rate is not in the 'supported formats' list: see around line 
870 of 'dlls/msacm/pcmconverter.c'. Hence the attached patch to 
pcmconverter. The changes in wavemap.c are just so that we at least try 
to see if we could convert to that sampling rate.

However, why only support conversion between these specific formats? Why 
not support anything between 100 and 10Hz for instance? That would 
nicely match the range returned by DirectSound...

Does this patch look ok?
Should I rewrite it using the above range instead? (Or rather, why 
should I not rewrite it that way?)

--
Francois Gouget
[EMAIL PROTECTED]

Index: dlls/msacm/pcmconverter.c
===
RCS file: /home/wine/wine/dlls/msacm/pcmconverter.c,v
retrieving revision 1.13
diff -u -r1.13 pcmconverter.c
--- dlls/msacm/pcmconverter.c   2 Dec 2002 18:10:59 -   1.13
+++ dlls/msacm/pcmconverter.c   11 Dec 2002 02:54:56 -
@@ -103,6 +103,7 @@
 {1,  8, 11025}, {2,  8, 11025}, {1, 16, 11025}, {2, 16, 11025},
 {1,  8, 22050}, {2,  8, 22050}, {1, 16, 22050}, {2, 16, 22050},
 {1,  8, 44100}, {2,  8, 44100}, {1, 16, 44100}, {2, 16, 44100},
+{1,  8, 48000}, {2,  8, 48000}, {1, 16, 48000}, {2, 16, 48000},
 };
 
 /***
Index: dlls/winmm/wavemap/wavemap.c
===
RCS file: /home/wine/wine/dlls/winmm/wavemap/wavemap.c,v
retrieving revision 1.24
diff -u -r1.24 wavemap.c
--- dlls/winmm/wavemap/wavemap.c31 Oct 2002 00:54:27 -  1.24
+++ dlls/winmm/wavemap/wavemap.c11 Dec 2002 02:55:03 -
@@ -189,26 +192,30 @@
 {wom->avgSpeedInner = wfx.nAvgBytesPerSec; goto found;}
 
 for (i = ndlo; i < ndhi; i++) {
 /* first try with same stereo/mono option as source */
 wfx.nChannels = lpDesc->lpFormat->nChannels;
+TRY(48000, 16);
 TRY(44100, 16);
 TRY(22050, 16);
 TRY(11025, 16);
 
 /* 2^3 => 1, 1^3 => 2, so if stereo, try mono (and the other way around) 
*/
 wfx.nChannels ^= 3;
+TRY(48000, 16);
 TRY(44100, 16);
 TRY(22050, 16);
 TRY(11025, 16);
 
 /* first try with same stereo/mono option as source */
 wfx.nChannels = lpDesc->lpFormat->nChannels;
+TRY(48000, 8);
 TRY(44100, 8);
 TRY(22050, 8);
 TRY(11025, 8);
 
 /* 2^3 => 1, 1^3 => 2, so if stereo, try mono (and the other way around) 
*/
 wfx.nChannels ^= 3;
+TRY(48000, 8);
 TRY(44100, 8);
 TRY(22050, 8);
 TRY(11025, 8);
@@ -217,7 +225,8 @@
 }
 
 HeapFree(GetProcessHeap(), 0, wom);
-return MMSYSERR_ALLOCATED;
+return WAVERR_BADFORMAT;
+
 found:
 if (dwFlags & WAVE_FORMAT_QUERY) {
*lpdwUser = 0L;



Re: Stretch Drawing

2002-12-11 Thread Mike Hearn
I think XV (xvideo) might have stuff for hardware scaling, it might be
worth asking on the xpert list. I was talking to somebody the other
night who reckoned Director was 4x slower under Wine than Windows,
potentially because Director thought it couldn't use hardware
acceleration and was doing all the rendering in software?

Something to investigate at some point

On Tue, 2002-12-10 at 23:03, Lionel Ulmer wrote:
> > Is anyone aware of this problem or am I misinterpreting the problem.  If
> > this is what's happening, is there an equivalent to XPutImage that requests
> > that the stretching operation be done in the graphics hardware which is going
> > to be considerably faster and almost instantaneous I would guess.
> 
> No, you're right. And such an API does not exist in 'standard' X AFAIK.
> Maybe in the Render extension used by Wine do to fonts, but I never really
> investigated it.
> 
>Lionel
--

Tony Lambregts

This would certainly work for me.

-- Jeff S

_
Add photos to your messages with MSN 8. Get 2 months FREE*. 
http://join.msn.com/?page=features/featuredemail




Re: wineoss/wavemap and i810 sound cards

2002-12-11 Thread Eric Pouech
Francois Gouget wrote:


Here's the problem: apparently i810 sound cards (and the corresponding 
OSS drivers) only accept 48kHz sound in 16 bit stereo. So if an 
application uses winmm to play a sound in any other format, winmm has to 
use the wave mapper to do the conversion to that format.

But msacm refuses to do a conversion to 48kHz sound because that 
sampling rate is not in the 'supported formats' list: see around line 
870 of 'dlls/msacm/pcmconverter.c'. Hence the attached patch to 
pcmconverter. The changes in wavemap.c are just so that we at least try 
to see if we could convert to that sampling rate.

However, why only support conversion between these specific formats? Why 
not support anything between 100 and 10Hz for instance? That would 
nicely match the range returned by DirectSound...

Does this patch look ok?
Should I rewrite it using the above range instead? (Or rather, why 
should I not rewrite it that way?)


msacm should indeed accept any possible conversion rate (I didn't check 
if a minimal/maximal range was enforced) (basically, you just need not 
to check for a correct rate when trying to accept or reject a given 
WAVEFORMATEX)

wavemapper should also support the new (XP ?) official rates of 48kHz 
and 96kHz

A+




Re: [patch] revert part of Aug 26 change in winmm/wineoss/audio.cthat broke msvc++4.0 installer?

2002-12-11 Thread Eric Pouech
Can someone who understands the code comment?


I don't, never looked at audio code before, but the above has two 
changes:

The condition has the '2 *' bit in it, and the body of the if has
+wwo->dwPlayedTotal = wwo->dwWrittenTotal;
The TRACEs are noops, can be ignored.

So I suggest trying them out individually, to see which one
causes the problem (or maybe they can not be separated). 
Experimentation will tell. :)


I tried each individually, and neither helped.  Only the two
changes together yielded a wine that properly terminated
when I clicked on the "Exit" button in msvc4++'s installer.
- Dan


a more complete fix should be included
could you try if it works fine ?

A+

Index: dlls/winmm/wineoss/audio.c
===
RCS file: /home/cvs/cvsroot/wine/wine/dlls/winmm/wineoss/audio.c,v
retrieving revision 1.65
diff -u -r1.65 audio.c
--- dlls/winmm/wineoss/audio.c  4 Nov 2002 22:39:19 -   1.65
+++ dlls/winmm/wineoss/audio.c  11 Dec 2002 20:21:45 -
@@ -1147,8 +1171,12 @@
 TRACE("fragments=%d/%d, fragsize=%d, bytes=%d\n",
  dspspace.fragments, dspspace.fragstotal, dspspace.fragsize, dspspace.bytes);
 
-/* input queue empty and output buffer with less than one fragment to play */
-if (!wwo->lpPlayPtr && wwo->dwBufferSize < availInQ + wwo->dwFragmentSize) {
+/* input queue empty and output buffer with less than one fragment to play 
+ * actually some cards do not play the fragment before the last if this one is 
+partially feed
+ * so we need to test for full the availability of 2 fragments
+ */
+if (!wwo->lpPlayPtr && wwo->dwBufferSize < availInQ + 2 * wwo->dwFragmentSize && 
+!wwo->bNeedPost) {
TRACE("Run out of wavehdr:s...\n");
 return INFINITE;
 }
@@ -1216,8 +1244,8 @@
TRACE("flushing\n");
ioctl(wwo->ossdev->fd, SNDCTL_DSP_SYNC, 0);
wwo->dwPlayedTotal = wwo->dwWrittenTotal;
-   }
-   else {
+dwNextNotifyTime = wodPlayer_NotifyCompletions(wwo, FALSE);
+   } else {
TRACE("recovering\n");
dwNextFeedTime = wodPlayer_FeedDSP(wwo);
}



RE: W2K results from the current tests

2002-12-11 Thread Rolf Kalbermatter
> >> W2K results from the current tests as downloaded from 
> >> http://fgouget.free.fr/wine/winetests.zip
> >>
> >> They seem to match the WinXP tests mostly ;-).
> >>
> >> Just one remark. The tests output all there results on stderr so to 
> >> redirect
> >> all info into a file when starting the batch file the command
> >>
> >> runtests.bat>>result.txt 2>&1
> >>
> >> seems very useful. This may not work on Win9x command prompts but it 
> >> does on
> >> W2K and XP.
> >
> runtests.bat>>result.txt 2>&1  does not work on Windows 98 and it is not 
> likely to work on any Win9x.

That's what I suspected. I didn't have the time to test it on Win95 but was
pretty sure that cmd.exe on Win9x would not be supporting these Unix like
features.

> > I wondered if the problem was output going to stderr.  I had not had
> > a chance to take a good look at it.  Is there anyway to tell the *test
> > programs* (i.e. not the script) to send output elsewhere, such as
> > stdout?  If not it should be added.  Then piping to a file should work
> > without any special incantations in Windows.  This is significant to me
> > now, as I am taking up Win98SE testing.
> >
> Is there any reason that I should not put a patch together that changes 
> the calls to stderr to stdout?

As far as I'm concerned I don't see why test results should go to stderr.
But I do not know about the possible background on Unix platforms for this.
If you want to do a patch I think this would be helpful and then see if
Alexandre is committing it ;-)

Rolf Kalbermatter





Re: W2K results from the current tests

2002-12-11 Thread Tony Lambregts
Jeff Smith wrote:


From: "Rolf Kalbermatter" <[EMAIL PROTECTED]>

W2K results from the current tests as downloaded from 
http://fgouget.free.fr/wine/winetests.zip

They seem to match the WinXP tests mostly ;-).

Just one remark. The tests output all there results on stderr so to 
redirect
all info into a file when starting the batch file the command

runtests.bat>>result.txt 2>&1

seems very useful. This may not work on Win9x command prompts but it 
does on
W2K and XP.


runtests.bat>>result.txt 2>&1  does not work on Windows 98 and it is not 
likely to work on any Win9x.


I wondered if the problem was output going to stderr.  I had not had
a chance to take a good look at it.  Is there anyway to tell the *test
programs* (i.e. not the script) to send output elsewhere, such as
stdout?  If not it should be added.  Then piping to a file should work
without any special incantations in Windows.  This is significant to me
now, as I am taking up Win98SE testing.


Is there any reason that I should not put a patch together that changes 
the calls to stderr to stdout?

-- 
Mike Hearn <[EMAIL PROTECTED]>
QinetiQ - Malvern Technology Center





Re: kernel32.spec update

2002-12-11 Thread Greg Turner
On Wednesday 11 December 2002 01:44 am, Francois Gouget wrote:
> undocumented

tell me about it.  *sigh*

-- 
gmt